""" Addon Information """
# ------------
# EventScripts Script-Addon:    BackRaw's RateChecker (BRC, brc.py, 4.7kb)
# Author:                       BackRaw - http://forums.eventscripts.com/profile.php?mode=viewprofile&u=13683
#                                         http://addons.eventscripts.com/addons/user/13683
# Version:                      1.1
# ------------

""" Imports """
# ------------
# EventScripts Core-Module            - ES-functionality
import es
# Popuplib                            - Create popups
import popuplib
# Config Object                       - Configuration-File: ./addons/eventscripts/brc/brc_config.ini
from configobj import ConfigObj
# ------------

""" Classes Configuration """
# ------------
# A simple small class that handles the configuration.
# If the configuration was changed (the file was saved with new settings), it can be used on-the-fly (no es_reload brc required)
# ------------
class config(object):
    """ Initialization """
    # Gets the configuration's path.
    def __init__(self):
        self.file = ConfigObj(es.getAddonPath('brc') + '/brc_config.ini')
    """ Say-Command """
    # Gets the current say-command.
    def sayCommand(self):
        return self.file['saycommand']
    """ Announce Message """
    # Gets the current announce message.
    def announceMessage(self):
        return int(self.file['announce'])

""" Message Handler """
# ------------
# This will handle all game-messages.
# If "announce" was set to 1 or more in the configuration file, it will announce new players.
# It will also tell the players what they'll have to type in the chat to open up the popup-menu.
# ------------
def msg(message, name=False):
    if config().announceMessage():
        t = 0
        if message != 'announce':
            t = 'to'
            if message == 'removed':
                t = 'from'
            t = '%s player #green%s #default%s the Check-Database...' % (message, name, t)
        else:
            t = 'Type #lightgreen%s #defaultin chat to get a list of players for checking their rates.' % config().sayCommand()
        es.msg('#multi', "#green[#lightgreenBackRaw's RateChecker#green] #default%s" % t)

""" Popup-Specific """
# ------------
# This small function will delete the named popup, if it exists.
# ------------
def delPopup(name):
    if popuplib.exists(name):
        popuplib.delete(name)

""" Popup-Menu """
# ------------
# This will get the choice's rates to check.
# ------------
def Menu(userid, choice, popupid):
    name = 'brc_tell_rates'
    delPopup(name)
    rate = popuplib.create(name)
    rate.addline("%s's Rates:" % es.getplayername(choice))
    rate.addline(' ')
    rate.addline('------------')
    rate.addline('Rate                   -      %s' % es.getclientvar(choice, 'rate'))
    rate.addline('CMD-Rate          -      %s' % es.getclientvar(choice, 'cl_cmdrate'))
    rate.addline('Update-Rate      -      %s' % es.getclientvar(choice, 'cl_updaterate'))
    rate.addline('------------')
    rate.send(userid)

""" Say Filter """
# ------------
# This will create a player-list, so it will be sent to the player that opened up the menu.
# ------------
def sayFilter(userid, text, teamonly):
    text = text.strip('"')
    if text == config().sayCommand():
        name = 'brc_rate_check'
        delPopup(name)
        menu = popuplib.easymenu(name, '_popup_choice', Menu)
        menu.settitle('Choose a Player...')
        for uid in es.getUseridList():
            menu.addoption(uid, es.getplayername(uid))
        menu.send(userid)
        return (None, None, None)
    return (userid, text, teamonly)

""" EventScripts Main-Control-Functions """
# ------------
# On load, just register the say-filter.
# ------------
def load():
    es.addons.registerSayFilter(sayFilter)

# ------------
# On unload, delete every created popup.
# ------------
def unload():
    es.addons.unregisterSayFilter(sayFilter)
    for x in ('rate_check', 'tell_rates'):
        delPopup('brc_%s' % x)

""" Events - These messages are only shown if "announce" was enabled (set to 1 or higher) in the configuration file """
# ------------
# Display a message that a new player can be checked.
# ------------
def player_activate(ev):
    msg('added', name=ev['es_username'])

# ------------
# Display a message that will tell the players what they have to type in the chat to open up the popup-menu.
# ------------
def round_start(ev):
    if announce:
        msg('announce')

# ------------
# Display a message that a player left and he/she can't be checked any more.
# ------------
def player_disconnect(ev):
    msg('removed', name=ev['name'])
